flutter_mpv_video_controls/src/controls/adaptive library

This file is a part of flutter_mpv (https://github.com/media-kit/media-kit).

Copyright © 2021 & onwards, Hitesh Kumar Saini saini123hitesh@gmail.com. All rights reserved. Use of this source code is governed by MIT license that can be found in the LICENSE file.

Functions

AdaptiveVideoControls(VideoState state) Widget
Video controls based on the running platform.