onVolumeChanged property
Optional callback called when volume should be changed (0.0 to 1.0). If not provided, volume gestures will be disabled.
Implementation
final void Function(double)? onVolumeChanged;
Optional callback called when volume should be changed (0.0 to 1.0). If not provided, volume gestures will be disabled.
final void Function(double)? onVolumeChanged;